@@ -491,7 +491,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     async def query(
         self, given_client: edgedb.AsyncIOClient = None, only_one: bool = False
-    ) -> T.Union[T.List[NodeType], NodeType]:
+    ) -> T.Union[T.List[NodeType], NodeType, None]:
         query_str = self.full_query_str()
         with safe_span(
             op=f"edgedb.query.{self._model_name}", description=query_str[:200]
